==> dde-introduction_5.6.38.orig.tar.xz: dde-introduction-5.6.38/translations/dde-introduction.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>Community</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>Feeback</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>Acknowledgments</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficient Mode</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion Mode</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Done</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Choose a desktop mode</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>You can switch modes by right clicking on the dock</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Choose a running mode</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>You can switch it in Control Center &gt; Personalization &gt; Window effect</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Choose an icon theme</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Change it in Control Center &gt; Personalization &gt; Icon Theme</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>Introduction</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Welcome</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>Desktop Mode</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Choose a desktop mode</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>You can switch modes by right clicking on the dock</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>Running Mode</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Choose a running mode</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>Please choose normal mode if you has a low configuration computer</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>Icon Theme</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Choose an icon theme</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Change it in Control Center &gt; Personalization &gt; Icon Theme</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>Welcome</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>Normal Mode</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>Effect Mode</translation>
    </message>
</context>
</TS>

==> dde-introduction_7.0.4.tar.xz: dde-introduction-7.0.4/translations/dde-introduction.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>Community</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>Feeback</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>Acknowledgments</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Align left</source>
        <translation>Align left</translation>
    </message>
    <message>
        <source>Align center</source>
        <translation>Align center</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Done</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Choose a running mode</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>You can switch it in Control Center &gt; Personalization &gt; Window effect</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Choose an icon theme</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Change it in Control Center &gt; Personalization &gt; Icon Theme</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Choose a desktop mode</translation>
    </message>
    <message>
        <source>You can switch alignment by right clicking on the dock</source>
        <translation>You can switch alignment by right clicking on the dock</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>Introduction</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Welcome</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>Desktop Mode</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>Running Mode</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Choose a running mode</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>Please choose normal mode if you has a low configuration computer</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>Icon Theme</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Choose an icon theme</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Change it in Control Center &gt; Personalization &gt; Icon Theme</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Choose a desktop mode</translation>
    </message>
    <message>
        <source>You can switch alignment by right clicking on the dock</source>
        <translation>You can switch alignment by right clicking on the dock</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>Welcome</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>Normal Mode</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>Effect Mode</translation>
    </message>
</context>
</TS>
